<?php $TRANSLATIONS = array(
"Save" => "保存",
"Close" => "关闭",
"Next" => "后一个",
"Clear" => "清空",
"Saving..." => "保存中...",
"An error occurred!" => "发生了一个错误！",
"There were unsaved changes, click here to go back" => "有未保存的修改，点此返回"
);
